pub struct ScannedPackage {
pub name: String,
pub version: String,
pub ecosystem: Ecosystem,
pub raw_license: Option<String>,
pub spdx_license: Option<String>,
pub classification: LicenseClass,
pub source: String,
}Expand description
A single package discovered during a scan with its resolved license.
Fields
name: Stringversion: Stringecosystem: Ecosystemraw_license: Option<String>Raw license string as found in the manifest or registry.
spdx_license: Option<String>Normalized SPDX identifier (e.g. “MIT”, “Apache-2.0”).
classification: LicenseClassHigh-level classification bucket.
source: StringWhere the license information came from (“manifest”, “registry”, “sbom”).